﻿// ----- Text Filtering Example
//       by Tim Patrick
//       for Visual Studio Magazine

using System.Collections.Generic;

namespace FilterList
{
    public class CityEntry : ITextFilter
    {
        public string CityState { get; set; }
        public List<string> ZipCode { get; set; }

        public CityEntry(string cityName, params string[] zipCodes)
        {
            // ----- Initialize with one or more zip codes.
            this.CityState = cityName;
            this.ZipCode = new List<string>();
            if (zipCodes != null)
                this.ZipCode.AddRange(zipCodes);
        }

        public bool IsMatch(string pattern)
        {
            // ----- See if city or zip matches the pattern.
            if (string.IsNullOrEmpty(pattern))
                return false;
            else if ((this.CityState != null) && (this.CityState.ToLower().Contains(pattern.ToLower())))
                return true;
            else if (this.ZipCode != null)
            {
                foreach (string oneZip in this.ZipCode)
                    if (oneZip.Contains(pattern))
                        return true;
            }
            return false;
        }

        public override string ToString()
        {
            // ----- Show the city name in bound situations.
            return this.CityState;
        }
    }
}
